==> v0.01.zip: hugo/content/de/Regeln.md <==
---
title: "Regeln der Mailingliste"
date: 2021-02-04T10:10:31+01:00
draft: false
---
Wir freuen uns, Dich auf unserer Liste begrüßen zu dürfen und möchten Dich auf einige, aber wichtige Regeln, hinweisen:

**1. Wir bitten Dich, alle Deine Mails in Nur-Text zu schreiben und keine HTML-Mails an die Liste zu schicken.**

Text-Mails haben den Vorteil, dass jeder Leser diese so auf seinem Bildschirm sieht, wie er es gerne hat und nicht einen bestimmten Stil (Schriftart, Farbe, Textgröße) aufgezwungen bekommt. Ein weiterer Nachteil von HTML-Mails ist, dass einige Mail-Programme (besonders die, die man in der Konsole laufen lässt) keine HTML-Mails darstellen können und der Leser zwischen den HTML-Tags lesen muss. (Hier bald ein fiktives Negativ-Beispiel)

**2. Erstelle neue Mails nicht mit dem "Antworten"-Button.**

Viele von uns verwenden Mailprogramme, die eine Thread-Ansicht bieten (z.B. Mozilla, kmail, mutt, Evolution). Dies ermöglicht es, zu erkennen, dass eine Mail als Antwort auf eine andere Mail geschrieben wurde und diese in einer Baumstruktur darzustellen. Daher solltest Du bitte folgendes beachten:

Wenn Du ein neues Thema aufmachen willst, dann bitte richtig: eine NEUE Mail an lugfrankfurt@lug-frankfurt.de (<- einfach mal anklicken :-) ) erstellen und nicht einfach auf eine bestehende antworten, sonst erscheinen diese Mails irgendwo in einem Thread, wo diese wirklich nichts verloren hat. Gerade "Freaks" sind es gewohnt, ganze Threads abzuhacken und dort nicht mehr mitzulesen. Und das ist bestimmt nicht in Deinem Sinne, oder??

Ausserdem soll es sich schon mehrfach als hilfreich erwiesen haben, einer Mail auch ein "Subject" zu geben, deshalb bitte die "Betreff"-Zeile mit knackig-kurzen und sinnvollen Informationen füttern...

**3. [RTFM](http://catb.org/~esr/jargon/html/R/RTFM.html)**

Jeder User der Liste wird normalerweise nach bestem Wissen und Gewissen antworten und Hilfestellungen leisten. Dennoch kommt es immer häufiger vor, dass einfache Fragen gestellt werden, welche sich mit Hilfe der manpages, der HOWTOs oder Google in wenigen Minuten von selber lösen würden. Bitte schau also erstmal auf den "Empfehlenswerten Webseiten", ob Du die Lösung selbst findest.

Als Vorgehensweise empfiehlt sich: [http://www.tty1.net/smart-questions_de.html](http://www.tty1.net/smart-questions_de.html)

Solltest Du noch nie mit Linux (oder Unix) gearbeitet haben, so bist Du uns natürlich ebenfalls herzlich willkommen. Du solltest Dir aber im Klaren darüber sein, dass Linux nicht Windows ist. Linux ist eine andere Welt, mit eigenen Regeln, eigenen Gesetzen und eigener "Kultur". Du musst vor allem bereit sein, Neues zu lernen. Als Einstieg hat sich ein Buch sehr bewährt. Dann müssen wir nicht jede Kleinigkeit ständig neu erklären.

Auch ergibt es sich häufig, dass ein Besuch bei unseren Treffen "Eis" abbaut und Dir dort auch Tipps für die ersten Gehversuche gegeben werden. Immerhin haben wir ALLE mal angefangen uns mit Linux zu beschäftigen... (Auch wenn sich einige nicht mehr richtig daran erinnern können :-)

**4. Spaß muß sein**

Witze sind erlaubt, gewollt und immer gesucht. Aber bitte möglichst nur "gute" Witze, die vielleicht auch was mit Linux oder Computer zu tun haben.

**5. Keine Glaubenskriege**

Gleiches gilt für Grundsatzdiskussionen, ala "Was ist besser Windows oder Linux"

Erfahrungsberichte sind gerne gesehen. Die wirklich interessanten Artikel können auf unserer Webseite veröffentlicht werden, wenn dies erwünscht/erlaubt ist.

**6. whois**

Es ist üblich, dass sich neue Leute kurz vorstellen. Dabei bitte auf Punkt 2 achten!

**7. https://lugfrankfurt.de**

Unsere Webseite ist https://lugfrankfurt.de. Jens (unser "WebMaster") ist manchmal ein Spielkind, und keiner weiss, welche Spielerei ihm als nächstes einfällt.

**8. Keine Auto-Replys**

Wenn ihr einen sogenannten Urlaubswarner benutzt, so meldet euch bitte während Eures Urlaubs von der Liste ab. Ansonsten behält sich der Mailinglistenadmin das Recht vor, Euch von der Liste zu schmeißen.

**9. Aus aktuellem Anlass: Jobangebote nur nach Absprache!**

Jobangebote bitte zuerst beim Mailinglistenadministrator fralug-ml-master jens.kuehnel.org (Bitte ein @ statt dem leerzeichen verwenden) "bestätigen" lassen, bevor sie an die Liste gesendet werden. Der Admin behält sich das Recht vor (und nimmt es auch wahr), Leute zu kicken, die sich nicht an diese Regel halten.

**10. Schalte den Ironie-Detektor™ ein**

Nicht alles, was wir schreiben, meinen wir auch ernst. Wer hier mitliest, sollte einen funktionstüchtigen Ironie-Detektor besitzen oder wissen, wie er Unerwünschtes filtern kann. Außerdem weisen wir darauf hin, dass die besten Sprüche in einer kleinen Fortunes Datenbank unter [Fortunes DB](/de/FortunesDB) zur Belustigung aller gesammelt wurden (und es könnte jemand auf die Idee kommen, damit wieder anzufangen).

**11. Realnames sind erwünscht**

Um die Kommunikation beim Stammtisch zu erleichtern, bitte auch auf der Mailingliste den richtigen Namen in Mails mit angeben. Es kann nur einen Tux geben!

**12. Kein Spam**

Damit die Mailingsliste nicht zugespammt wird, darf die Liste nicht mit unerwünschter Werbung belästigt werden. Dazu gehören auch Einladungen von Facebook, LinkedIn, Xing oder ähnlichen Webseiten.

==> v0.03.zip: hugo/content/de/Regeln.md <==
---
title: "Regeln der Mailingliste"
date: 2021-02-04T10:10:31+01:00
draft: false
---
Wir freuen uns, Dich auf unserer Liste begrüßen zu dürfen und möchten Dich auf einige, aber wichtige Regeln, hinweisen:

**1. Wir bitten Dich, alle Deine Mails in Nur-Text zu schreiben und keine HTML-Mails an die Liste zu schicken.**

Text-Mails haben den Vorteil, dass jeder Leser diese so auf seinem Bildschirm sieht, wie er es gerne hat und nicht einen bestimmten Stil (Schriftart, Farbe, Textgröße) aufgezwungen bekommt. Ein weiterer Nachteil von HTML-Mails ist, dass einige Mail-Programme (besonders die, die man in der Konsole laufen lässt) keine HTML-Mails darstellen können und der Leser zwischen den HTML-Tags lesen muss. (Hier bald ein fiktives Negativ-Beispiel)

**2. Erstelle neue Mails nicht mit dem "Antworten"-Button.**

Viele von uns verwenden Mailprogramme, die eine Thread-Ansicht bieten (z.B. Mozilla, kmail, mutt, Evolution). Dies ermöglicht es, zu erkennen, dass eine Mail als Antwort auf eine andere Mail geschrieben wurde und diese in einer Baumstruktur darzustellen. Daher solltest Du bitte folgendes beachten:

Wenn Du ein neues Thema aufmachen willst, dann bitte richtig: eine NEUE Mail an lugfrankfurt@lug-frankfurt.de (<- einfach mal anklicken :-) ) erstellen und nicht einfach auf eine bestehende antworten, sonst erscheinen diese Mails irgendwo in einem Thread, wo diese wirklich nichts verloren hat. Gerade "Freaks" sind es gewohnt, ganze Threads abzuhacken und dort nicht mehr mitzulesen. Und das ist bestimmt nicht in Deinem Sinne, oder??

Ausserdem soll es sich schon mehrfach als hilfreich erwiesen haben, einer Mail auch ein "Subject" zu geben, deshalb bitte die "Betreff"-Zeile mit knackig-kurzen und sinnvollen Informationen füttern...

**3. {{<tabref href=http://catb.org/~esr/jargon/html/R/RTFM.html" title="RTFM">}}**

Jeder User der Liste wird normalerweise nach bestem Wissen und Gewissen antworten und Hilfestellungen leisten. Dennoch kommt es immer häufiger vor, dass einfache Fragen gestellt werden, welche sich mit Hilfe der manpages, der HOWTOs oder Google in wenigen Minuten von selber lösen würden. Bitte schau also erstmal auf den "Empfehlenswerten Webseiten", ob Du die Lösung selbst findest.

Als Vorgehensweise empfiehlt sich: {{<tabref href="http://www.tty1.net/smart-questions_de.html" title="http://www.tty1.net/smart-questions_de.html">}}

Solltest Du noch nie mit Linux (oder Unix) gearbeitet haben, so bist Du uns natürlich ebenfalls herzlich willkommen. Du solltest Dir aber im Klaren darüber sein, dass Linux nicht Windows ist. Linux ist eine andere Welt, mit eigenen Regeln, eigenen Gesetzen und eigener "Kultur". Du musst vor allem bereit sein, Neues zu lernen. Als Einstieg hat sich ein Buch sehr bewährt. Dann müssen wir nicht jede Kleinigkeit ständig neu erklären.

Auch ergibt es sich häufig, dass ein Besuch bei unseren Treffen "Eis" abbaut und Dir dort auch Tipps für die ersten Gehversuche gegeben werden. Immerhin haben wir ALLE mal angefangen uns mit Linux zu beschäftigen... (Auch wenn sich einige nicht mehr richtig daran erinnern können :-)

**4. Spaß muß sein**

Witze sind erlaubt, gewollt und immer gesucht. Aber bitte möglichst nur "gute" Witze, die vielleicht auch was mit Linux oder Computer zu tun haben.

**5. Keine Glaubenskriege**

Gleiches gilt für Grundsatzdiskussionen, ala "Was ist besser Windows oder Linux"

Erfahrungsberichte sind gerne gesehen. Die wirklich interessanten Artikel können auf unserer Webseite veröffentlicht werden, wenn dies erwünscht/erlaubt ist.

**6. whois**

Es ist üblich, dass sich neue Leute kurz vorstellen. Dabei bitte auf Punkt 2 achten!

**7. https://lugfrankfurt.de**

Unsere Webseite ist https://lugfrankfurt.de. Jens (unser "WebMaster") ist manchmal ein Spielkind, und keiner weiss, welche Spielerei ihm als nächstes einfällt.

**8. Keine Auto-Replys**

Wenn ihr einen sogenannten Urlaubswarner benutzt, so meldet euch bitte während Eures Urlaubs von der Liste ab. Ansonsten behält sich der Mailinglistenadmin das Recht vor, Euch von der Liste zu schmeißen.

**9. Aus aktuellem Anlass: Jobangebote nur nach Absprache!**

Jobangebote bitte zuerst beim Mailinglistenadministrator fralug-ml-master jens.kuehnel.org (Bitte ein @ statt dem leerzeichen verwenden) "bestätigen" lassen, bevor sie an die Liste gesendet werden. Der Admin behält sich das Recht vor (und nimmt es auch wahr), Leute zu kicken, die sich nicht an diese Regel halten.

**10. Schalte den Ironie-Detektor™ ein**

Nicht alles, was wir schreiben, meinen wir auch ernst. Wer hier mitliest, sollte einen funktionstüchtigen Ironie-Detektor besitzen oder wissen, wie er Unerwünschtes filtern kann. Außerdem weisen wir darauf hin, dass die besten Sprüche in einer kleinen Fortunes Datenbank unter [Fortunes DB](/de/FortunesDB) zur Belustigung aller gesammelt wurden (und es könnte jemand auf die Idee kommen, damit wieder anzufangen).

**11. Realnames sind erwünscht**

Um die Kommunikation beim Stammtisch zu erleichtern, bitte auch auf der Mailingliste den richtigen Namen in Mails mit angeben. Es kann nur einen Tux geben!

**12. Kein Spam**

Damit die Mailingsliste nicht zugespammt wird, darf die Liste nicht mit unerwünschter Werbung belästigt werden. Dazu gehören auch Einladungen von Facebook, LinkedIn, Xing oder ähnlichen Webseiten.
